@@ -48,7 +48,7 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
@@ -63,6 +63,9 @@
 #define MOD_VERSION "v0.3.10 (2003-07-24)"
 #define MOD_CODEC   "(video) DivX 4.x/5.x | (audio) MPEG/AC3/PCM"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_AC3|TC_CAP_AUD;
+
 #define MOD_PRE divx4
 #include "export_def.h"
 
@@ -73,7 +76,6 @@ static avi_t *avifile=NULL;
   
 //temporary audio/video buffer
 static char *buffer;
-#define BUFFER_SIZE SIZE_RGB_FRAME<<1
 
 // We'll allocate (and zero) DIVX_STRUCT_PADDING beyond the required size of
 // the ENC_PARAM structure.  This is in case a later version of the library API
@@ -90,9 +92,6 @@ ENC_RESULT    key;
 static int encore_version = 0;
 static int divx_version = 0;
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_AC3|TC_CAP_AUD;
-
 // dl stuff
 static int (*divx_encore)(void *para0, int opt, void *para1, void *para2);
 static void *handle;
@@ -102,7 +101,7 @@ static char module[TC_BUF_MAX];
 #define MODULE_V "libdivxencore.so.0"
 
 static int divx_init(char *path) {
-#if defined(__FreeBSD__) || defined(__APPLE__) /* Just in case ProjectMayo will release FreeBSD library :-) */  
+#ifdef SYS_BSD  /* Just in case ProjectMayo will release FreeBSD library :-) */  
   const
 #endif  
   char *error;
@@ -260,11 +259,11 @@ MOD_init
       }
     }
     
-    if ((buffer = malloc(BUFFER_SIZE))==NULL) {
+    if ((buffer = malloc(vob->ex_v_height*vob->ex_v_width*3))==NULL) {
       perror("out of memory");
       return(TC_EXPORT_ERROR); 
     } else
-      memset(buffer, 0, BUFFER_SIZE);  
+      memset(buffer, 0, vob->ex_v_height*vob->ex_v_width*3);  
 
     //load the codec
 
