@@ -49,7 +49,7 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
@@ -69,6 +69,9 @@
 #define MOD_VERSION "v0.1.8 (2003-07-24)"
 #define MOD_CODEC   "(video) DivX 5.xx | (audio) MPEG/AC3/PCM"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_AC3|TC_CAP_AUD;
+
 #define MOD_PRE divx5
 #include "export_def.h"
 
@@ -79,7 +82,6 @@ static avi_t *avifile=NULL;
   
 //temporary audio/video buffer
 static char *buffer;
-#define BUFFER_SIZE SIZE_RGB_FRAME<<1
 
 #if ENCORE_VERSION >= 20021024
 DivXBitmapInfoHeader *format =NULL;
@@ -92,9 +94,6 @@ ENC_PARAM   *divx;
 ENC_FRAME  encode;
 ENC_RESULT    key;
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_AC3|TC_CAP_AUD;
-
 // dl stuff
 static int (*divx5_encore)(void *para0, int opt, void *para1, void *para2);
 static void *handle;
@@ -118,7 +117,7 @@ static char * prof2name(int n)
 #define MODULE "libdivxencore.so.0"
 
 static int divx5_init(char *path) {
-#if defined(__FreeBSD__) || defined(__APPLE__) /* Just in case ProjectMayo will release FreeBSD library :-) */  
+#ifdef SYS_BSD /* Just in case ProjectMayo will release FreeBSD library :-) */  
   const
 #endif  
   char *error;
@@ -212,12 +211,12 @@ MOD_init
       }
     }
     
-    if ((buffer = malloc(BUFFER_SIZE))==NULL) {
+    if ((buffer = malloc(vob->ex_v_height*vob->ex_v_width*3))==NULL) {
       perror("out of memory");
       return(TC_EXPORT_ERROR); 
     } else
       
-    memset(buffer, 0, BUFFER_SIZE);  	
+    memset(buffer, 0, vob->ex_v_height*vob->ex_v_width*3);  	
 
     //load the codec
 
