@@ -33,12 +33,13 @@
 #define MOD_VERSION "v0.0.3 (2003-03-06)"
 #define MOD_CODEC   "(audio) MPEG 1/2"
 
+static int 			verbose_flag	= TC_QUIET;
+static int 			capability_flag	= TC_CAP_PCM;
+
 #define MOD_PRE lame
 #include "export_def.h"
 
 static FILE* 			pFile 		= NULL;
-static int 			verbose_flag	= TC_QUIET;
-static int 			capability_flag	= TC_CAP_PCM;
 
 /* ------------------------------------------------------------ 
  *
@@ -71,6 +72,10 @@ static int p_write (char *buf, size_t len)
 
 MOD_open
 {
+
+  /* check for lame */
+  if (tc_test_program("lame") != 0) return (TC_EXPORT_ERROR);
+
   if (param->flag == TC_AUDIO) {
     char buf [PATH_MAX];
     int ifreq,ofreq,orate;
@@ -80,6 +85,7 @@ MOD_open
     int ochan;
     char chan;
     char *ptr = buf;
+	const char * swap_bytes = "";
     
     char br[64];
 
@@ -112,6 +118,10 @@ MOD_open
     ofreq_dec = ofreq-ofreq_int*1000;
 	    
     /* lame command line */
+
+#if !defined(WORDS_BIGENDIAN)
+	swap_bytes = "-x";
+#endif
     
     switch(vob->a_vbr) {
 
@@ -132,8 +142,8 @@ MOD_open
       break;
     }      
     
-    sprintf(ptr, "lame %s -s %d.%03d -m %c - \"%s.mp3\" 2>/dev/null %s", 
-	    br, ofreq_int, ofreq_dec, chan, vob->audio_out_file, (vob->ex_a_string?vob->ex_a_string:""));
+    sprintf(ptr, "lame -x %s %s %d.%03d -m %c - \"%s.mp3\" 2>/dev/null %s", 
+	    swap_bytes, br, ofreq_int, ofreq_dec, chan, vob->audio_out_file, (vob->ex_a_string?vob->ex_a_string:""));
     
     fprintf (stderr,"[%s] cmd=%s\n", MOD_NAME, buf);
     
