@@ -27,7 +27,7 @@
 #include "transcode.h"
 #include "avilib.h"
 #include "aud_aux.h"
-#include "../import/magic.h"
+#include "import/magic.h"
 
 #include <lzo1x.h>
 #if (LZO_VERSION > 0x1070)
@@ -45,17 +45,16 @@
 #define MOD_VERSION "v0.0.6 (2003-07-24)"
 #define MOD_CODEC   "(video) LZO real-time compression | (audio) MPEG/AC3/PCM"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_DV|TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_AC3|TC_CAP_AUD|TC_CAP_VID;
+
 #define MOD_PRE lzo
 #include "export_def.h"
 
-#define BUFFER_SIZE SIZE_RGB_FRAME<<1
 
 static avi_t *avifile1=NULL;
 static avi_t *avifile2=NULL;
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_DV|TC_CAP_PCM|TC_CAP_RGB|TC_CAP_YUV|TC_CAP_AC3|TC_CAP_AUD|TC_CAP_VID;
-
 static int info_shown=0, force_kf=0;
 
 static int r;
@@ -86,7 +85,7 @@ MOD_init
       }
 
       wrkmem = (lzo_bytep) lzo_malloc(LZO1X_1_MEM_COMPRESS);
-      out = (lzo_bytep) lzo_malloc(BUFFER_SIZE);
+      out = (lzo_bytep) lzo_malloc(vob->ex_v_height*vob->ex_v_width*3*2);
 
       if (wrkmem == NULL || out == NULL) {
 	printf("[%s] out of memory\n", MOD_NAME);
@@ -208,7 +207,7 @@ MOD_encode
     h.flags |= ((codec==CODEC_RGB)?TC_LZO_FORMAT_RGB24:TC_LZO_FORMAT_YV12);
 
     // XXX
-    memcpy (out, &h, sizeof(h));
+    tc_memcpy (out, &h, sizeof(h));
 #else
     r = lzo1x_1_compress(param->buffer, param->size, out, &out_len, wrkmem);
 #endif
