@@ -44,12 +44,14 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
-#if !defined(__FreeBSD__) && !defined(__APPLE__) /* We have malloc() in stdlib.h */
-#include <malloc.h>
+#ifndef SYS_BSD /* We have malloc() in stdlib.h */
+# ifdef HAVE_MALLOC_H
+# include <malloc.h>
+# endif
 #endif
 
 #if 1
@@ -64,7 +66,7 @@
 #include "aud_aux.h"
 
 #ifdef DEVELOPER_USE
-#include "../libioaux/configs.h"
+#include "libioaux/configs.h"
 #endif
 
 /*****************************************************************************
@@ -75,6 +77,14 @@
 #define MOD_VERSION "v0.3.12 (2003-07-30)"
 #define MOD_CODEC  \
 "(video) XviD nonumber series (aka API 3.0)  | (audio) MPEG/AC3/PCM"
+
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_PCM |
+                             TC_CAP_RGB |
+                             TC_CAP_YUV |
+                             TC_CAP_AC3 |
+                             TC_CAP_YUV422 |
+                             TC_CAP_AUD;
 #define MOD_PRE xvid3_ 
 #include "export_def.h"
 
@@ -94,15 +104,6 @@ static int rawfd = -1;
   
 /* temporary audio/video buffer */
 static char *buffer;
-#define BUFFER_SIZE SIZE_RGB_FRAME<<1
-
-static int verbose_flag = TC_QUIET;
-static int capability_flag = TC_CAP_PCM |
-                             TC_CAP_RGB |
-                             TC_CAP_YUV |
-                             TC_CAP_AC3 |
-                             TC_CAP_YUV422 |
-                             TC_CAP_AUD;
 
 /*****************************************************************************
  * Prototypes for shared library symbols
@@ -173,14 +174,15 @@ MOD_init
 		return(audio_init(vob, verbose));
 
 	if(param->flag == TC_VIDEO) {
+		int fsize = vob->ex_v_width * vob->ex_v_height;
 		bpp = 1000 * (vob->divxbitrate) / 
 			(vob->ex_fps * vob->ex_v_width * vob->ex_v_height);
     
-		if((buffer = malloc(BUFFER_SIZE))==NULL) {
+		if((buffer = malloc(fsize*3))==NULL) {
 			perror("out of memory");
 			return(TC_EXPORT_ERROR); 
 		} else {
-			memset(buffer, 0, BUFFER_SIZE);  
+			memset(buffer, 0, fsize*3);  
 		}
 
 		/* Load the codec */
@@ -244,19 +246,19 @@ MOD_init
 
 		switch(vob->im_v_codec) {
 		case CODEC_RGB:	
-			global_framesize = SIZE_RGB_FRAME;
+			global_framesize = fsize*3;
 			global_colorspace = XVID_CSP_RGB24|XVID_CSP_VFLIP;
 			break;
 		case CODEC_YUV:
-			global_framesize = SIZE_RGB_FRAME*2/3;
+			global_framesize = fsize*3/2;
 			global_colorspace = XVID_CSP_YV12;
 			break;
 		case CODEC_YUV422:
-			global_framesize = SIZE_RGB_FRAME*2/3;
+			global_framesize = fsize*2;
 			global_colorspace = XVID_CSP_UYVY;
 			break;
 		default: /* down know... simply use YV12, too... */
-			global_framesize = SIZE_RGB_FRAME*2/3;
+			global_framesize = fsize*3/2;
 			global_colorspace = XVID_CSP_YV12;
 			break;
 		}			
@@ -589,7 +591,7 @@ MOD_stop
 
 static int xvid2_init(char *path)
 {
-#if defined(__FreeBSD__) || defined(__APPLE__)
+#ifdef SYS_BSD
 	const
 #endif    
 		char *error;
