@@ -44,12 +44,14 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
-#if !defined(__FreeBSD__) && !defined(__APPLE__)
-#include <malloc.h>
+#ifndef SYS_BSD
+# ifdef HAVE_MALLOC_H
+# include <malloc.h>
+# endif
 #endif
 
 #include "xvid4.h"
@@ -58,7 +60,7 @@
 #include "avilib.h"
 #include "aud_aux.h"
 
-#include "../libioaux/configs.h"
+#include "libioaux/configs.h"
 
 /*****************************************************************************
  * Transcode module binding functions and strings
@@ -68,6 +70,13 @@
 #define MOD_VERSION "v0.0.5 (2003-12-05)"
 #define MOD_CODEC  \
 "(video) XviD 1.0.x series (aka API 4.0) | (audio) MPEG/AC3/PCM"
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_PCM |
+                             TC_CAP_RGB |
+                             TC_CAP_YUV |
+                             TC_CAP_YUV422 |
+                             TC_CAP_AC3 |
+                             TC_CAP_AUD;
 #define MOD_PRE xvid4_ 
 #include "export_def.h"
 
@@ -82,13 +91,6 @@
 extern char* tc_config_dir;
 
 /* Temporary audio/video buffer */
-static int verbose_flag = TC_QUIET;
-static int capability_flag = TC_CAP_PCM |
-                             TC_CAP_RGB |
-                             TC_CAP_YUV |
-                             TC_CAP_YUV422 |
-                             TC_CAP_AC3 |
-                             TC_CAP_AUD;
 
 /*****************************************************************************
  * XviD symbols grouped in a nice struct.
@@ -535,7 +537,7 @@ static void reset_module(xvid_transcode_module_t *mod)
 	mod->rawfd = -1;
 
 	/* Default options */
-	mod->cfg_packed = 1;
+	mod->cfg_packed = 0;
 	mod->cfg_closed_gop = 1;
 	mod->cfg_interlaced = 0;
 	mod->cfg_quarterpel = 0;
@@ -550,7 +552,7 @@ static void reset_module(xvid_transcode_module_t *mod)
 	mod->cfg_stats = 0;
 	mod->cfg_greyscale = 0;
 	mod->cfg_quant_method = strdup("h263");
-	mod->cfg_create.max_bframes = 2;
+	mod->cfg_create.max_bframes = 1;
 	mod->cfg_create.bquant_ratio = 150;
 	mod->cfg_create.bquant_offset = 100;
 
@@ -1022,6 +1024,10 @@ static void set_frame_struct(xvid_transcode_module_t *mod, vob_t *vob, transfer_
 
 	/* pixel aspect ratio
 	 * transcode.c uses 0 for EXT instead of 15 */
+	if ((vob->ex_par==0) && 
+	    (vob->ex_par_width==1) && (vob->ex_par_height==1)) 
+	    vob->ex_par = 1;
+
 	x->par = (vob->ex_par==0)? XVID_PAR_EXT: vob->ex_par;
 	x->par_width = vob->ex_par_width;
 	x->par_height = vob->ex_par_height;
@@ -1154,7 +1160,7 @@ static void print_matrix(unsigned char *matrix)
 
 static int load_xvid(xvid_module_t *xvid, char *path)
 {
-#if defined(__FreeBSD__) || defined(__APPLE__)
+#ifdef SYS_BSD
 	const char *error;
 #else
 	char *error;
