@@ -49,10 +49,6 @@ extern void yuv_antialias(char *image, char *dest, int width, int height, int mo
  *
  *-------------------------------------------------*/
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "transcode.h"
 #include "dl_loader.h"
 #include "framebuffer.h"
@@ -246,7 +242,7 @@ void anti_alias_subtitle(int black) {
   //use transcode's anti-alias routine (full frame mode = 3)
   if(!skip_anti_alias) {
     yuv_antialias(sub_frame, tmp_frame, sub_xlen, sub_ylen, 3);
-    memcpy(sub_frame, tmp_frame, sub_xlen * sub_ylen);
+    tc_memcpy(sub_frame, tmp_frame, sub_xlen * sub_ylen);
   }
 
   anti_alias_done=1;
