@@ -46,9 +46,10 @@
 #include "transcode.h"
 #include "framebuffer.h"
 
-#include "../libioaux/framecode.h"
+#include "libioaux/framecode.h"
 
 extern int max_frame_buffer;
+extern void tc_import_stop(void);
 
 
 /*-------------------------------------------------
