@@ -57,7 +57,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
   static vob_t *vob=NULL;
   static char *lines = NULL;
-  static int width, height, height_mod, codec;
+  static int width, height, codec;
   int h;
   static int evenfirst=0;
 
@@ -172,21 +172,21 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
 	  ptr->attributes |= TC_FRAME_IS_CLONED;
 
-	  memcpy (lines, ptr->video_buf, ptr->video_size);
+	  tc_memcpy (lines, ptr->video_buf, ptr->video_size);
 
 	  for (h = 0; h < height/2; h++) {
-	      memcpy (p, s, stride);
+	      tc_memcpy (p, s, stride);
 	      s += 2*stride;
 	      p +=   stride;
 	  }
 	  if (codec==CODEC_YUV) {
 	      for (h = 0; h < height/4; h++) {
-		  memcpy (p, s, stride/2);
+		  tc_memcpy (p, s, stride/2);
 		  s += 2*stride/2;
 		  p +=   stride/2;
 	      }
 	      for (h = 0; h < height/4; h++) {
-		  memcpy (p, s, stride/2);
+		  tc_memcpy (p, s, stride/2);
 		  s += 2*stride/2;
 		  p +=   stride/2;
 	      }
@@ -201,19 +201,19 @@ int tc_filter(vframe_list_t *ptr, char *options)
 	 // printf("WAS cloned\n");
 
 	  for (h = 0; h < height/2; h++) {
-	      memcpy (p, s, stride);
+	      tc_memcpy (p, s, stride);
 	      s += 2*stride;
 	      p +=   stride;
 	  }
 
 	  if (codec==CODEC_YUV) {
 	      for (h = 0; h < height/4; h++) {
-		  memcpy (p, s, stride/2);
+		  tc_memcpy (p, s, stride/2);
 		  s += 2*stride/2;
 		  p +=   stride/2;
 	      }
 	      for (h = 0; h < height/4; h++) {
-		  memcpy (p, s, stride/2);
+		  tc_memcpy (p, s, stride/2);
 		  s += 2*stride/2;
 		  p +=   stride/2;
 	      }
