@@ -16,6 +16,7 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #include "subtitler.h"
 
+extern int parse_frame_entry(struct frame *pa);
 
 int hash(s)/* form hash value for string s */
 char *s;
@@ -33,8 +34,8 @@ return(hashval % FRAME_HASH_SIZE);
 
 char *strsave(char *s) /*save char array s somewhere*/
 {
-char *p, *malloc();
-if(p = malloc( strlen(s) +  1) ) strcpy(p, s);
+char *p;
+if((p = malloc( strlen(s) +  1))) strcpy(p, s);
 return(p);
 }
 
@@ -125,7 +126,6 @@ int add_frame(\
 	int xsize, int ysize, int zsize, int id)
 {
 struct frame *pa;
-char *ptr;
 
 if(debug_flag)
 	{
@@ -136,7 +136,7 @@ if(debug_flag)
 	xsize=%d ysize=%d zsize=%d\n\
 	id=%d\n",\
 	name,\
-	data,\
+	(unsigned long)data,\
 	object_type,\
 	xsize, ysize, zsize,\
 	id);
@@ -207,8 +207,10 @@ if(debug_flag)
 sprintf(temp, "%d", frame_nr);
 for(pa = frametab[hash(temp)]; pa != 0; pa = pa -> nxtentr)
 	{
-//printf("WAS pa->type=%d pa->name=%s frame_nr=%d end_frame=%d\n",\
-//pa -> type, pa -> name, frame_nr, end_frame);
+#if 0
+	printf("WAS pa->type=%d pa->name=%s frame_nr=%d end_frame=%d\n",\
+	pa -> type, pa -> name, frame_nr, end_frame);
+#endif
 
 	if(pa -> type == FORMATTED_TEXT)
 		{
@@ -361,7 +363,7 @@ struct subtitle_fontname *ps;
 font_desc_t *pfd;
 char temp[4096];
 
-//if(debug_flag)
+if(debug_flag)
 	{
 	fprintf(stdout,\
 	"add_font(): arg name=%s symbols=%d size=%d iso_extension=%d outline_thickness=%.2f blur_radius=%.2f\n",\
