@@ -36,7 +36,7 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
@@ -54,7 +54,7 @@ static void *handle;
 static char module[TC_BUF_MAX];
 
 int af6_init(char *path) {
-#ifdef __FreeBSD__
+#ifdef SYS_BSD
     const
 #endif    
     char *error;
