@@ -34,14 +34,14 @@
 #include <dlfcn.h>
 #else
 # ifdef SYSTEM_DARWIN
-#  include "../libdldarwin/dlfcn.h"
+#  include "libdldarwin/dlfcn.h"
 # endif
 #endif
 
 #include "transcode.h"
 #include "ioaux.h"
 
-#include "../export/xvid2.h"
+#include "export/xvid2.h"
 
 #define MOD_NAME    "decode_xvid"
 
@@ -61,7 +61,7 @@ static int x_dim, y_dim;
 
 static int xvid2_init(char *path) {
 
-#ifdef __FreeBSD__
+#ifdef SYS_BSD
 	const
 #endif    
 		char *error;
@@ -262,7 +262,7 @@ void decode_xvid(decode_t *decode)
 
 	    /* Move data if needed */
 	    if (rest)
-		memcpy(in_buffer, mp4_ptr, rest);
+		tc_memcpy(in_buffer, mp4_ptr, rest);
 
 	    /* Update mp4_ptr */
 	    mp4_ptr = in_buffer; 
