@@ -39,13 +39,13 @@
 #include <errno.h>
 #include <sys/stat.h>
 #include <sys/mman.h>
-
 #include <limits.h>
-#include <ac3.h>
-#include "avilib.h"
+
+#include "ac3.h"
 #include "ioaux.h"
 #include "aux_pes.h"
 #include "tc.h"
+#include "transcode.h"
 
 #define BUFFER_SIZE 262144
 static uint8_t *buffer = NULL;
@@ -77,6 +77,7 @@ static void pes_ac3_loop (void)
 
     unsigned int pack_lpts=0;
     double pack_rpts=0.0f, last_rpts=0.0f, offset_rpts=0.0f, abs_rpts=0.0f;
+    double pack_sub_rpts=0.0f, abs_sub_rpts=0.0f;
 
     int discont=0;
 
@@ -139,12 +140,12 @@ static void pes_ac3_loop (void)
 	  }
 	  
 	  // get pts time stamp:
-	  memcpy(pack_buf, &buf[6], 16);
+	  tc_memcpy(pack_buf, &buf[6], 16);
 	  
 	  if(get_pts_dts(pack_buf, &i_pts, &i_dts)) {
 	    pack_rpts = (double) i_pts/90000.;
 	    
-	    if(pack_rpts < last_rpts){
+	    if(pack_rpts < last_rpts){ // pts resets when a new chapter begins
 	      offset_rpts += last_rpts;
 	      ++discont;
 	    }  
@@ -162,7 +163,7 @@ static void pes_ac3_loop (void)
 	case 0xba:	/* pack header */
 	  
 	  if(get_pts) {
-	    memcpy(pack_buf, &buf[4], 6);
+	    tc_memcpy(pack_buf, &buf[4], 6);
 	    pack_lpts = read_tc_time_stamp(pack_buf);
 	  }
 
@@ -205,25 +206,38 @@ static void pes_ac3_loop (void)
 	  if(verbose & TC_STATS) fprintf(stderr,"track code 0x%x\n", *tmp1); 
 	  
 	  if(vdr_work_around) {
-	    if (tmp1 < tmp2) fwrite (tmp1, tmp2-tmp1, 1, stdout);
+	    if (tmp1 < tmp2) fwrite (tmp1, tmp2-tmp1, 1, out_file);
 	  } else {
 
-	    //subttitle
+	    //subtitle
 	    
 	    if (*tmp1 == track_code && track_code < 0x40) {   
 	      
 	      if (tmp1 < tmp2) {
 		
 		// get pts time stamp:
+		  tc_memcpy(pack_buf, &buf[6], 16);
+
+		  if(get_pts_dts(pack_buf, &i_pts, &i_dts)) {
+		    pack_sub_rpts = (double) i_pts/90000.;
+	    
+		    //i suppose there *canNOT* be 2 sub chunks from the
+		    //same sub line over a chapter change
+		    //let's add the video offset to the subs
+		    abs_sub_rpts=pack_sub_rpts + offset_rpts;
+	    
+		    //fprintf(stderr, "sub PTS=%8.3f ABS=%8.3f\n", pack_rpts, abs_rpts);
+		  }
+
 		subtitle_header.lpts = pack_lpts;
-		subtitle_header.rpts = abs_rpts;
+		subtitle_header.rpts = abs_sub_rpts;
 		subtitle_header.discont_ctr = discont;
 		subtitle_header.header_version = TC_SUBTITLE_HDRMAGIC;
 		subtitle_header.header_length = sizeof(subtitle_header_t);
 		subtitle_header.payload_length=tmp2-tmp1;
 		
 		if(verbose & TC_STATS) 
-		  fprintf(stderr,"subtitle=0x%x size=%4d lpts=%d rpts=%f\n", track_code, tmp2-tmp1, subtitle_header.lpts, subtitle_header.rpts); 
+		  fprintf(stderr,"subtitle=0x%x size=%4d lpts=%d rpts=%f rptsfromvid=%f\n", track_code, tmp2-tmp1, subtitle_header.lpts, subtitle_header.rpts,abs_rpts); 
 		
 		if(p_write(STDOUT_FILENO, (char*) subtitle_header_str, strlen(subtitle_header_str))<0) {
 		  fprintf(stderr, "error writing subtitle\n");
@@ -247,12 +261,12 @@ static void pes_ac3_loop (void)
 		
 		//test
 		if(0) {
-		    memcpy(pack_buf, &buf[6], 16);
+		    tc_memcpy(pack_buf, &buf[6], 16);
 		    get_pts_dts(pack_buf, &i_pts, &i_dts);
 		    fprintf(stderr, "AC3 PTS=%f\n", (double) i_pts/90000.);
 		}
 		
-		if (tmp1 < tmp2) fwrite (tmp1, tmp2-tmp1, 1, stdout);
+		if (tmp1 < tmp2) fwrite (tmp1, tmp2-tmp1, 1, out_file);
 	    }
 	  }
 	  
