@@ -24,13 +24,16 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-
+#include <xio.h>
 #include "transcode.h"
 
 #define MOD_NAME    "import_dv.so"
 #define MOD_VERSION "v0.3.1 (2003-10-14)"
 #define MOD_CODEC   "(video) DV | (audio) PCM"
 
+static int verbose_flag=TC_QUIET;
+static int capability_flag=TC_CAP_RGB|TC_CAP_YUV|TC_CAP_DV|TC_CAP_PCM|TC_CAP_VID|TC_CAP_YUV422;
+
 #define MOD_PRE dv
 #include "import_def.h"
 
@@ -38,9 +41,6 @@
 #define MAX_BUF 1024
 char import_cmd_buf[MAX_BUF];
 
-static int verbose_flag=TC_QUIET;
-static int capability_flag=TC_CAP_RGB|TC_CAP_YUV|TC_CAP_DV|TC_CAP_PCM|TC_CAP_VID|TC_CAP_YUV422;
-
 static int frame_size=0;
 static FILE *fd=NULL;
 
@@ -48,7 +48,7 @@ int scan(char *name)
 {
   struct stat fbuf;
   
-  if(stat(name, &fbuf)) {
+  if(xio_stat(name, &fbuf)) {
     fprintf(stderr, "(%s) invalid file \"%s\"\n", __FILE__, name);
     exit(1);
   }
