@@ -27,15 +27,21 @@
 #include <string.h>
 
 #include "transcode.h"
-#include "../ffmpeg/libavcodec/avcodec.h"
+// FIXME
+#undef EMULATE_FAST_INT
+#include <ffmpeg/avcodec.h>
 #include "yuv2rgb.h"
 #include "avilib.h"
 #include "magic.h"
 
 #define MOD_NAME    "import_ffmpeg.so"
-#define MOD_VERSION "v0.1.10 (2003-12-30)"
+#define MOD_VERSION "v0.1.11 (2004-02-29)"
 #define MOD_CODEC   "(video)  " LIBAVCODEC_IDENT \
                     ": MS MPEG4v1-3/MPEG4/MJPEG"
+
+static int verbose_flag = TC_QUIET;
+static int capability_flag = TC_CAP_YUV|TC_CAP_RGB|TC_CAP_VID;
+
 #define MOD_PRE ffmpeg
 #include "import_def.h"
 
@@ -48,8 +54,6 @@ char import_cmd_buf[MAX_BUF];
 
 extern pthread_mutex_t init_avcodec_lock;
 
-static int verbose_flag = TC_QUIET;
-static int capability_flag = TC_CAP_YUV|TC_CAP_RGB|TC_CAP_VID;
 static int done_seek=0;
 
 struct ffmpeg_codec {
@@ -110,7 +114,7 @@ static int                 pass_through = 0;
 static char               *buffer =  NULL;
 static char               *yuv2rgb_buffer = NULL;
 static AVCodec            *lavc_dec_codec = NULL;
-static AVCodecContext     *lavc_dec_context;
+static AVCodecContext     *lavc_dec_context = NULL;
 static int                 x_dim = 0, y_dim = 0;
 static int                 pix_fmt, frame_size = 0, bpp;
 static char                *frame = NULL;
@@ -331,7 +335,7 @@ do_avi:
     lavc_dec_context->error_resilience = 2;
     lavc_dec_context->error_concealment = 3;
     lavc_dec_context->workaround_bugs = FF_BUG_AUTODETECT;
-    lavc_dec_context->stream_codec_tag= (fourCC[0]<<24)|(fourCC[1]<<16)|(fourCC[2]<<8)|fourCC[0];
+    lavc_dec_context->codec_tag= (fourCC[0]<<24)|(fourCC[1]<<16)|(fourCC[2]<<8)|fourCC[3];
 
     // XXX: some codecs need extra data
     switch (codec->id)
@@ -361,6 +365,7 @@ do_avi:
     
     pix_fmt = vob->im_v_codec;
     
+    frame_size = x_dim * y_dim * 3;
     switch (pix_fmt) {
       case CODEC_YUV:
         frame_size = (x_dim * y_dim * 3)/2;
@@ -399,14 +404,14 @@ do_avi:
     //
     //----------------------------------------
     
-    if(buffer == NULL) buffer=bufalloc(BUFFER_SIZE);
+    if(buffer == NULL) buffer=bufalloc(frame_size);
     
     if(buffer == NULL) {
       perror("out of memory");
       return TC_IMPORT_ERROR;
     }
 
-    memset(buffer, 0, BUFFER_SIZE);  
+    memset(buffer, 0, frame_size);  
     
     param->fd = NULL;
 
@@ -486,19 +491,14 @@ MOD_decode {
   long       bytes_read = 0;
   int        got_picture, UVls, src, dst, row, col;
   char      *Ybuf, *Ubuf, *Vbuf;
-  int        retry;
   AVFrame  picture;
 
   if (param->flag == TC_VIDEO) {
     bytes_read = AVI_read_frame(avifile, buffer, &key);
 
-    if (bytes_read < 0) {
-      return TC_IMPORT_ERROR;
-    }
+    if (bytes_read < 0) return TC_IMPORT_ERROR;
     
-    if (key) {
-      param->attributes |= TC_FRAME_IS_KEYFRAME;
-    }
+    if (key) param->attributes |= TC_FRAME_IS_KEYFRAME;
 
     // PASS_THROUGH MODE
 
@@ -524,14 +524,14 @@ MOD_decode {
 	if (key || bkey) printf("[%s] Keyframe info (AVI | Bitstream) (%d|%d)\n", MOD_NAME, key, bkey);
 
       param->size = (int) bytes_read;
-      memcpy(param->buffer, buffer, bytes_read); 
+      tc_memcpy(param->buffer, buffer, bytes_read); 
 
       return TC_IMPORT_OK;
     }
 
     if (bytes_read == 0) {
         // repeat last frame
-        memcpy(param->buffer, frame, frame_size);
+        tc_memcpy(param->buffer, frame, frame_size);
         param->size = frame_size;
         return 0;
     }
@@ -540,8 +540,7 @@ MOD_decode {
     // decode frame
     // ------------
 
-    // safety counter
-    retry = 0;
+retry:
     do {
       pthread_mutex_lock(&init_avcodec_lock);
       len = avcodec_decode_video(lavc_dec_context, &picture, 
@@ -552,12 +551,24 @@ MOD_decode {
 	tc_warn ("[%s] frame decoding failed", MOD_NAME);
         return TC_IMPORT_ERROR;
       }
-    } while (!got_picture && ++retry<1000);
+      if (!got_picture) {
+	if (avifile->video_pos == 1) {
 
-    if (retry >= 1000) {
-      tc_warn("[%s] tried a 1000 times but could not decode frame", MOD_NAME);
-      return TC_IMPORT_ERROR;
-    }
+	  bytes_read = AVI_read_frame(avifile, buffer, &key);
+	  if (bytes_read < 0) return TC_IMPORT_ERROR;
+	  param->attributes &= ~TC_FRAME_IS_KEYFRAME;
+	  if (key) param->attributes |= TC_FRAME_IS_KEYFRAME;
+	  goto retry;
+
+	} else {
+
+	  // repeat last frame
+	  tc_memcpy(param->buffer, frame, frame_size);
+	  param->size = frame_size;
+	  return 0;
+	}
+      }
+    } while (0);
 
     Ybuf = frame;
     Ubuf = Ybuf + lavc_dec_context->width * lavc_dec_context->height;
@@ -571,15 +582,15 @@ MOD_decode {
         if (pix_fmt == CODEC_YUV) {
           edge_width = (picture.linesize[0] - lavc_dec_context->width) / 2;
           for (i = 0; i < lavc_dec_context->height; i++) {
-            memcpy(Ybuf + i * lavc_dec_context->width,
+            tc_memcpy(Ybuf + i * lavc_dec_context->width,
                    picture.data[0] + i * picture.linesize[0], //+ edge_width,
                    lavc_dec_context->width);
           }
           for (i = 0; i < lavc_dec_context->height / 2; i++) {
-            memcpy(Vbuf + i * lavc_dec_context->width / 2,
+            tc_memcpy(Vbuf + i * lavc_dec_context->width / 2,
                    picture.data[1] + i * picture.linesize[1],// + edge_width / 2,
                    lavc_dec_context->width / 2);
-            memcpy(Ubuf + i * lavc_dec_context->width / 2,
+            tc_memcpy(Ubuf + i * lavc_dec_context->width / 2,
                    picture.data[2] + i * picture.linesize[2],// + edge_width / 2,
                    lavc_dec_context->width / 2);
           }
@@ -589,17 +600,17 @@ MOD_decode {
           Vbuf = Ubuf + lavc_dec_context->width * lavc_dec_context->height / 4;
           edge_width = (picture.linesize[0] - lavc_dec_context->width) / 2;
           for (i = 0; i < lavc_dec_context->height; i++) {
-            memcpy(Ybuf + (lavc_dec_context->height - i - 1) *
+            tc_memcpy(Ybuf + (lavc_dec_context->height - i - 1) *
                      lavc_dec_context->width,
                    picture.data[0] + i * picture.linesize[0], //+ edge_width,
                    lavc_dec_context->width);
           }
           for (i = 0; i < lavc_dec_context->height / 2; i++) {
-            memcpy(Vbuf + (lavc_dec_context->height / 2 - i - 1) *
+            tc_memcpy(Vbuf + (lavc_dec_context->height / 2 - i - 1) *
                      lavc_dec_context->width / 2,
                    picture.data[1] + i * picture.linesize[1],// + edge_width / 2,
                    lavc_dec_context->width / 2);
-            memcpy(Ubuf + (lavc_dec_context->height / 2 - i - 1) *
+            tc_memcpy(Ubuf + (lavc_dec_context->height / 2 - i - 1) *
                      lavc_dec_context->width / 2,
                    picture.data[2] + i * picture.linesize[2],// + edge_width / 2,
                    lavc_dec_context->width / 2);
@@ -618,19 +629,26 @@ MOD_decode {
         break;
       case PIX_FMT_YUV422P:
           // Result is in YUV 4:2:2 format (subsample UV vertically for YV12):
-          memcpy(Ybuf, picture.data[0], picture.linesize[0] * lavc_dec_context->height);
+          for (i = 0; i < lavc_dec_context->height; i++) {
+            tc_memcpy(Ybuf + i * lavc_dec_context->width,
+                   picture.data[0] + i * picture.linesize[0], //+ edge_width,
+                   lavc_dec_context->width);
+          }
+
           src = 0;
           dst = 0;
           for (row=0; row<lavc_dec_context->height; row+=2) {
-            memcpy(Ubuf + dst, picture.data[1] + src, UVls);
-            memcpy(Vbuf + dst, picture.data[2] + src, UVls);
-            dst += UVls;
-            src = dst << 1;
-          }
+			for (col=0; col<lavc_dec_context->width/2; col++) {
+			  Vbuf[dst + col] = (picture.data[1][src + col] + picture.data[1][src + UVls + col]) >> 1;
+			  Ubuf[dst + col] = (picture.data[2][src + col] + picture.data[2][src + UVls + col]) >> 1;
+			}
+            dst += lavc_dec_context->width >> 1;
+            src += UVls << 1;
+          } 
 	  break;
       case PIX_FMT_YUV444P:
           // Result is in YUV 4:4:4 format (subsample UV h/v for YV12):
-	  memcpy(Ybuf, picture.data[0], picture.linesize[0] * lavc_dec_context->height);
+	  tc_memcpy(Ybuf, picture.data[0], picture.linesize[0] * lavc_dec_context->height);
           src = 0;
           dst = 0;
           for (row=0; row<lavc_dec_context->height; row+=2) {
@@ -649,7 +667,7 @@ MOD_decode {
 	  // 4:1:1 -> 4:2:0
 
           for (i = 0; i < lavc_dec_context->height; i++) {
-            memcpy(Ybuf + i * lavc_dec_context->width,
+            tc_memcpy(Ybuf + i * lavc_dec_context->width,
                    picture.data[0] + i * picture.linesize[0], 
                    lavc_dec_context->width);
           }
@@ -666,7 +684,7 @@ MOD_decode {
           Ubuf = Ybuf + lavc_dec_context->width * lavc_dec_context->height;
           Vbuf = Ubuf + lavc_dec_context->width * lavc_dec_context->height / 4;
           for (i = 0; i < lavc_dec_context->height; i++) {
-            memcpy(Ybuf + i * lavc_dec_context->width,
+            tc_memcpy(Ybuf + i * lavc_dec_context->width,
                    picture.data[0] + i * picture.linesize[0], 
                    lavc_dec_context->width);
           }
@@ -694,7 +712,7 @@ MOD_decode {
 	return TC_IMPORT_ERROR;
     }
 
-    memcpy(param->buffer, frame, frame_size);
+    tc_memcpy(param->buffer, frame, frame_size);
     param->size = frame_size;
 
     return 0;
@@ -714,14 +732,18 @@ MOD_close {
   if (param->flag == TC_VIDEO) {
 
     if(lavc_dec_context) {
-      avcodec_flush_buffers(lavc_dec_context);
+      if (!pass_through)
+	avcodec_flush_buffers(lavc_dec_context);
       
       avcodec_close(lavc_dec_context);
+      if (lavc_dec_context->extradata_size) free(lavc_dec_context->extradata);
       free(lavc_dec_context);
 
       lavc_dec_context = NULL;
       done_seek=0;
 
+      pass_through = 0;
+
     }
     
     if (param->fd) pclose(param->fd);
