@@ -28,12 +28,14 @@
 #include "config.h"
 #endif
 
-#ifdef LAME_3_89
+#ifdef HAVE_LAME
+
 #ifdef HAVE_LAME_INC
 #include <lame/lame.h>
 #else
 #include <lame.h>
 #endif
+
 #include "ioaux.h"
 #include "magic.h"
 
@@ -41,6 +43,7 @@ int lame_decode_initfile(FILE * fd, mp3data_struct * mp3data, int format);
 int lame_decode_fromfile(FILE * fd, short pcm_l[], short pcm_r[], mp3data_struct * mp3data);
 
 int buf_probe_mp3(unsigned char *_buf, int len, pcm_t *pcm);
-#endif
+
+#endif  // HAVE_LAME
 
 #endif
