@@ -21,6 +21,9 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include "transcode.h"
 #include "dl_loader.h"
 #include "framebuffer.h"
@@ -37,8 +40,8 @@ static FILE *fd_ppm=NULL, *fd_pcm=NULL;
 static void *import_ahandle, *import_vhandle;
 
 // import flags (1=import active | 0=import closed)
-static int aimport=0;
-static int vimport=0;
+static volatile int aimport=0;
+static volatile int vimport=0;
 static pthread_mutex_t import_v_lock=PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t import_a_lock=PTHREAD_MUTEX_INITIALIZER;
 
@@ -91,6 +94,9 @@ void tc_import_stop()
 //
 //-------------------------------------------------------------------------
 
+#ifdef HAVE_IBP
+extern pthread_mutex_t xio_lock;
+#endif
 
 void import_threads_cancel()
 {
@@ -99,6 +105,10 @@ void import_threads_cancel()
 
   int cc1, cc2;
 
+#ifdef HAVE_IBP
+  pthread_mutex_lock(&xio_lock);
+#endif
+
   if (tc_decoder_delay)
       printf("\n(%s) sleeping for %d seconds to cool down\n", __FILE__, 2*tc_decoder_delay);
 
@@ -121,6 +131,9 @@ void import_threads_cancel()
   //wait for threads to terminate
 #ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
   pthread_cond_signal(&vframe_list_full_cv);
+#endif
+#ifdef HAVE_IBP
+      pthread_mutex_unlock(&xio_lock);
 #endif
   cc1=pthread_join(vthread, &status);
   
@@ -128,22 +141,24 @@ void import_threads_cancel()
   
 #ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
   pthread_cond_signal(&aframe_list_full_cv);
+#endif
+#ifdef HAVE_IBP
+      pthread_mutex_unlock(&xio_lock);
 #endif
   cc2=pthread_join(athread, &status);
   
   if(verbose & TC_DEBUG) fprintf(stderr, "(%s) audio thread exit (ret_code=%d) (status_code=%d)\n", __FILE__, cc2, (int) status);
 
-  
   cc1 = pthread_mutex_trylock(&vframe_list_lock);
   
   if(verbose & TC_DEBUG) fprintf(stderr, "(%s) vframe_list_lock=%s\n", __FILE__, (cc1==EBUSY)? "BUSY":"0");
-  pthread_mutex_unlock(&vframe_list_lock);
+  if(cc1 == 0) pthread_mutex_unlock(&vframe_list_lock);
   
   cc2 = pthread_mutex_trylock(&aframe_list_lock);
   
   if(verbose & TC_DEBUG) fprintf(stderr, "(%s) aframe_list_lock=%s\n", __FILE__, (cc2==EBUSY)? "BUSY":"0");
-  pthread_mutex_unlock(&aframe_list_lock);
-  
+  if(cc2 == 0) pthread_mutex_unlock(&aframe_list_lock);
+
   return;
 
 }
@@ -178,115 +193,135 @@ void import_threads_create(vob_t *vob)
 //-------------------------------------------------------------------------
 
 int import_init(vob_t *vob, char *a_mod, char *v_mod)
-{  
-  
-  transfer_t import_para;
-  
-  memset(&import_para, 0, sizeof(transfer_t));
+{
+	transfer_t import_para;
+	int cc;
 
-  // load audio import module
-  
-  if((import_ahandle=load_module(((a_mod==NULL)? TC_DEFAULT_IMPORT_AUDIO: a_mod), TC_IMPORT+TC_AUDIO))==NULL) {
-    fprintf(stderr, "(%s) loading audio import module failed\n", __FILE__);
-    return(-1);
-  }
+	memset(&import_para, 0, sizeof(transfer_t));
 
-  aimport_start();
-  
-  // load video import module
-  if((import_vhandle=load_module(((v_mod==NULL)? TC_DEFAULT_IMPORT_VIDEO: v_mod), TC_IMPORT+TC_VIDEO))==NULL) {
-    fprintf(stderr, "(%s) loading video import module failed\n", __FILE__);
-    return(-1);
-  }
-  
-  vimport_start();
+	// load audio import module
 
-  // check import module capability, inherit verbosity flag
+	if((import_ahandle=load_module(((a_mod==NULL)? TC_DEFAULT_IMPORT_AUDIO: a_mod), TC_IMPORT+TC_AUDIO))==NULL)
+	{
+		fprintf(stderr, "Loading audio import module failed\n");
+		fprintf(stderr, "Did you enable this module when you ran configure?\n");
+		return(-1);
+	}
 
-  import_para.flag = verbose;
-  tca_import(TC_IMPORT_NAME, &import_para, NULL); 
-  
-  if(import_para.flag != verbose) {
-    // module returned capability flag
-    
-    int cc=0;
-    
-    if(verbose & TC_DEBUG) 
-      fprintf(stderr, "(%s) audio capability flag 0x%x | 0x%x\n", __FILE__, import_para.flag, vob->im_a_codec);    
-    
-    switch (vob->im_a_codec) {
-      
-    case CODEC_PCM: 
-      cc=(import_para.flag & TC_CAP_PCM);
-      break;
-    case CODEC_AC3: 
-      cc=(import_para.flag & TC_CAP_AC3);
-      break;
-    case CODEC_RAW: 
-      cc=(import_para.flag & TC_CAP_AUD);
-      break;
-    default:
-      cc=0;
-    }
+	aimport_start();
 
-    if(!cc) {
-      fprintf(stderr, "(%s) audio codec not supported by import module\n", __FILE__); 
-      return(-1);
-    }
-    
-  } else {
-    
-    if(vob->im_a_codec != CODEC_PCM) {
-      fprintf(stderr, "(%s) audio codec not supported by import module\n", __FILE__); 
-      return(-1);
-    }
-  }
+	// load video import module
 
-  import_para.flag = verbose;
-  tcv_import(TC_IMPORT_NAME, &import_para, NULL);
-  
-  if(import_para.flag != verbose) {
-    // module returned capability flag
-    
-    int cc=0;
-    
-    if(verbose & TC_DEBUG) 
-      fprintf(stderr, "(%s) video capability flag 0x%x | 0x%x\n", __FILE__, import_para.flag, vob->im_v_codec);
-    
-    switch (vob->im_v_codec) {
-      
-    case CODEC_RGB: 
-      cc=(import_para.flag & TC_CAP_RGB);
-      break;
-    case CODEC_YUV: 
-      cc=(import_para.flag & TC_CAP_YUV);
-      break;
-    case CODEC_YUV422: 
-      cc=(import_para.flag & TC_CAP_YUV422);
-      break;
-    case CODEC_RAW_YUV: 
-    case CODEC_RAW: 
-      cc=(import_para.flag & TC_CAP_VID);
-      break;
-    default:
-      cc=0;
-    }
-    
-    if(!cc) {
-      fprintf(stderr, "(%s) video codec not supported by import module\n", __FILE__); 
-      return(-1);
-    }
-    
-  } else {
-    
-    if(vob->im_v_codec != CODEC_RGB) {
-      fprintf(stderr, "(%s) video codec not supported by import module\n", __FILE__); 
-      return(-1);
-    }
-  }
+	if((import_vhandle=load_module(((v_mod==NULL)? TC_DEFAULT_IMPORT_VIDEO: v_mod), TC_IMPORT+TC_VIDEO))==NULL)
+	{
+		fprintf(stderr, "Loading video import module failed\n");
+		fprintf(stderr, "Did you enable this module when you ran configure?\n");
+		return(-1);
+	}
 
-  return(0);
-  
+	vimport_start();
+
+	// check import module capability, inherit verbosity flag
+
+	import_para.flag = verbose;
+	tca_import(TC_IMPORT_NAME, &import_para, NULL); 
+
+	if(import_para.flag != verbose)
+	{
+		// module returned capability flag
+		if(verbose & TC_DEBUG) 
+			fprintf(stderr, "Audio capability flag 0x%x | 0x%x\n", import_para.flag, vob->im_a_codec);
+
+		switch (vob->im_a_codec)
+		{
+			case CODEC_PCM: 
+			{
+				cc=(import_para.flag & TC_CAP_PCM);
+				break;
+			}
+	
+			case CODEC_AC3: 
+			{
+				cc=(import_para.flag & TC_CAP_AC3);
+				break;
+			}
+	
+			case CODEC_RAW: 
+			{
+				cc=(import_para.flag & TC_CAP_AUD);
+				break;
+			}
+	
+			default:
+			{
+				cc=0;
+			}
+		}
+	}
+	else
+		cc = vob->im_a_codec == CODEC_PCM;
+
+	
+	if(!cc)
+	{
+		fprintf(stderr, "Audio format not supported by import module\n"); 
+		return(-1);
+	}
+
+	import_para.flag = verbose;
+	tcv_import(TC_IMPORT_NAME, &import_para, NULL);
+
+	if(import_para.flag != verbose)
+	{
+		// module returned capability flag
+
+		if(verbose & TC_DEBUG) 
+			fprintf(stderr, "Video capability flag 0x%x | 0x%x\n", import_para.flag, vob->im_v_codec);
+
+		switch (vob->im_v_codec)
+		{
+			case CODEC_RGB: 
+			{
+				cc=(import_para.flag & TC_CAP_RGB);
+				break;
+			}
+
+			case CODEC_YUV: 
+			{
+				cc=(import_para.flag & TC_CAP_YUV);
+				break;
+			}
+
+			case CODEC_YUV422: 
+			{
+				cc=(import_para.flag & TC_CAP_YUV422);
+				break;
+			}
+
+			case CODEC_RAW_YUV: 
+			case CODEC_RAW: 
+			{
+				cc=(import_para.flag & TC_CAP_VID);
+				break;
+			}
+
+			default:
+			{
+				cc=0;
+			}
+		}
+	}
+	else
+		cc = vob->im_v_codec == CODEC_RGB;
+
+	if(!cc)
+	{
+		fprintf(stderr, "Video format not supported by import module\n"); 
+		fprintf(stderr, "Please try --use_uyvy and --use_rgb\n");
+		return(-1);
+	}
+
+	return(0);
 }
 
 //-------------------------------------------------------------------------
@@ -434,6 +469,12 @@ static int mfread(char *buf, int size, int nelem, FILE *f)
   return (nelem);
 }
 
+static void
+import_lock_cleanup (void *arg)
+{
+  pthread_mutex_unlock ((pthread_mutex_t *)arg);
+}
+
 //-------------------------------------------------------------------------
 //
 // video import thread
@@ -469,6 +510,8 @@ void vimport_thread(vob_t *vob)
     //check buffer fill level
     pthread_mutex_lock(&vframe_list_lock);
     
+    pthread_cleanup_push (import_lock_cleanup, &vframe_list_lock);
+
     while(vframe_fill_level(TC_BUFFER_FULL)) {
 	pthread_cond_wait(&vframe_list_full_cv, &vframe_list_lock);
 #ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
@@ -477,10 +520,12 @@ void vimport_thread(vob_t *vob)
 	
 	// check for pending shutdown via ^C
 	if(vimport_test_shutdown()) {
-	  pthread_mutex_unlock(&vframe_list_lock);
 	  pthread_exit( (int *) 11);
 	}
     }
+
+    pthread_cleanup_pop (0);
+
     pthread_mutex_unlock(&vframe_list_lock);
     
     // get a frame buffer or wait
@@ -657,6 +702,8 @@ void aimport_thread(vob_t *vob)
     //check buffer fill level
     pthread_mutex_lock(&aframe_list_lock);
     
+    pthread_cleanup_push (import_lock_cleanup, &aframe_list_lock);
+
     while(aframe_fill_level(TC_BUFFER_FULL)) {
       pthread_cond_wait(&aframe_list_full_cv, &aframe_list_lock);
 #ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
@@ -665,11 +712,12 @@ void aimport_thread(vob_t *vob)
 
       // check for pending shutdown via ^C
       if(aimport_test_shutdown(TEST_ON_BUFFER_FULL)) {
-	pthread_mutex_unlock(&aframe_list_lock);
 	pthread_exit( (int *) 11);
       }
     }
     
+    pthread_cleanup_pop (0);
+
     pthread_mutex_unlock(&aframe_list_lock);
     
     // get a frame buffer or wait
@@ -943,16 +991,17 @@ void aimport_start()
 int aimport_status()
 {
   
-  int cc=0;
+  int cc;
 
   pthread_mutex_lock(&import_a_lock);
 
-  if(aimport) {
-    pthread_mutex_unlock(&import_a_lock);
-    return(aimport);
-  }
+  cc = aimport;
+
   pthread_mutex_unlock(&import_a_lock);
 
+  if (cc)
+    return 1;
+
   // decoder finished, check for frame list
   pthread_mutex_lock(&aframe_list_lock);
   
@@ -981,16 +1030,16 @@ void aimport_notify()
 int vimport_status()
 {
   
-  int cc=0;
+  int cc;
 
   pthread_mutex_lock(&import_v_lock);
 
-  if(vimport) {
-    pthread_mutex_unlock(&import_v_lock);
-    return(vimport);
-  }
+  cc = vimport;
 
   pthread_mutex_unlock(&import_v_lock);
+
+  if (cc)
+    return 1;
   
   // decoder finished, check for frame list
   pthread_mutex_lock(&vframe_list_lock);
