@@ -30,7 +30,7 @@
 #include "avilib.h"
 #include "config.h"
 #include "transcode.h"
-#include "libioaux/framecode.h"
+#include "framecode.h"
 #include "aud_scan.h"
 
 #define EXE "avisplit"
@@ -122,6 +122,8 @@ int main(int argc, char *argv[])
 
   char separator[] = ",";
 
+  tc_memcpy_init(0, -1);
+
   if(argc==1) usage(EXIT_FAILURE);
   memset(byte_count_at_start, 0 , sizeof(long)*AVI_MAX_TRACKS);
   
